@@ -38,22 +38,33 @@ class ARS():
             path = default_path
         self.config.read(path)
 
-    def run(self):
+    def run(self, sys_args):
+        profile_arg, region_arg = self.parse_arguments(sys_args)
         self.init()
-        profile = self.prompt_for_profile_name()
+        profile = self.prompt_for_profile_name(profile_arg)
         if profile:
             self.set_aws_environment_variables(profile)
+        if not os.environ.get("AWS_DEFAULT_REGION"):
+            self.set_aws_region(region_arg)
+
+    def parse_arguments(self, sys_args):
+        if len(sys_args) <= 1:
+            return "", ""
+        elif len(sys_args) == 2:
+            return sys_args[1], ""
+        else:
+            return sys_args[1], sys_args[2]
+
 
     def set_aws_environment_variables(self, profile):
         variables = ["AWS_SECRET_ACCESS_KEY", "AWS_ACCESS_KEY_ID", "AWS_SESSION_TOKEN", "AWS_SECURITY_TOKEN"]
         for k, v in self.config[profile].items():
             if k.upper() in variables:
                 print(f"export {k.upper()}={v}")
-        if not os.environ.get("AWS_DEFAULT_REGION"):
-            self.set_aws_region()
 
-    def set_aws_region(self):
-        region = prompt('AWS_DEFAULT_REGION Not Set. Choose Region: ', completer=FuzzyWordCompleter(REGIONS))
+
+    def set_aws_region(self, arg):
+        region = prompt('AWS_DEFAULT_REGION Not Set. Choose Region: ', default=arg, completer=FuzzyWordCompleter(REGIONS))
         if self.validate(region, REGIONS):
             print(f"export AWS_DEFAULT_REGION={region}")
 
@@ -63,9 +74,9 @@ class ARS():
         else:
             raise Exception(f"{raw} is not valid, must be one of {expected}")
 
-    def prompt_for_profile_name(self):
+    def prompt_for_profile_name(self, arg):
         res = None
-        profile = prompt('Enter Profile: ', completer=FuzzyWordCompleter(self.config.sections()),
+        profile = prompt('Enter Profile: ', default=arg, completer=FuzzyWordCompleter(self.config.sections()),
                          complete_while_typing=True)
         if self.validate(profile, self.config.sections()):
             res = profile
